summaryrefslogtreecommitdiffstats
path: root/cmake_admin/FindKDECONFIG.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake_admin/FindKDECONFIG.cmake')
-rw-r--r--cmake_admin/FindKDECONFIG.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/cmake_admin/FindKDECONFIG.cmake b/cmake_admin/FindKDECONFIG.cmake
index 5679434..fd640ba 100644
--- a/cmake_admin/FindKDECONFIG.cmake
+++ b/cmake_admin/FindKDECONFIG.cmake
@@ -20,7 +20,7 @@
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version. See the file
# COPYING included with this distribution for more information.
# Find the kde-config program and retrieve the install dirs
# Variables:
# HAVE_KDECONFIG
@@ -37,13 +37,13 @@
IF(KDECONFIG_EXECUTABLE)
SET(HAVE_KDECONFIG TRUE)
ELSE(KDECONFIG_EXECUTABLE)
- FIND_PROGRAM(KDECONFIG_EXECUTABLE NAMES kde-config PATHS
+ FIND_PROGRAM(KDECONFIG_EXECUTABLE NAMES tde-config PATHS
$ENV{TDEDIR}/bin
/opt/trinity/bin
/opt/kde/bin
NO_DEFAULT_PATH
)
- FIND_PROGRAM(KDECONFIG_EXECUTABLE kde-config)
+ FIND_PROGRAM(KDECONFIG_EXECUTABLE tde-config)
ENDIF(KDECONFIG_EXECUTABLE)
IF(NOT KDE3PREFIX)
@@ -20,7 +20,7 @@
# License, or (at your option) any later version. See the file
# COPYING included with this distribution for more information.
-# Find the kde-config program and retrieve the install dirs
+# Find the tde-config program and retrieve the install dirs
# Variables:
# HAVE_KDECONFIG